==> openGion_core_5.7.6.0.zip: ge/db/sqlserver/sql/install/01_TABLE/GE56S.sql <==
/****************************************************************************/
/* GE56 ( 帳票ｴﾗｰﾃｰﾌﾞﾙ )                                                    */
/*                                                                          */
/* Created : 2014/03/26 15:25:58                                            */
/****************************************************************************/
CREATE TABLE GE56 (
   SYSTEM_ID    varchar           (   10 )                  NOT NULL            /*  10 ｼｽﾃﾑID       */
 , YKNO         INTEGER                         DEFAULT 0   NOT NULL            /*  20 要求NO       */
 , ERRMSG       varchar           ( 4000 )                                      /*  30 ｴﾗｰﾒｯｾｰｼﾞ    */
 , UNIQSEQ      int IDENTITY(1,1)                                               /*  50 ｼｰｹﾝｽ番号    */
 , FGJ          varchar           (    1 )      DEFAULT 1   NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        varchar           (   14 )                                      /* 820 登録日時     */
 , PGSET        varchar           (   10 )                                      /* 830 作成PG       */
 , PGPSET       varchar           (   10 )                                      /* 840 作成親PG     */
 , USRSET       varchar           (   10 )                                      /* 850 作成社員     */
 , DYUPD        varchar           (   14 )                                      /* 860 更新日時     */
 , PGUPD        varchar           (   10 )                                      /* 870 更新PG       */
 , PGPUPD       varchar           (   10 )                                      /* 880 更新親PG     */
 , USRUPD       varchar           (   10 )                                      /* 890 更新者       */
);

==> openGion_core_5.9.20.0.zip: ge/db/sqlserver/sql/install/01_TABLE/GE56S.sql <==
/****************************************************************************/
/* GE56 ( 帳票ｴﾗｰﾃｰﾌﾞﾙ )                                                    */
/*                                                                          */
/* Created : 2017/05/02 11:07:53                                            */
/****************************************************************************/
CREATE TABLE GE56 (
   SYSTEM_ID    varchar           (   10 )                  NOT NULL            /*  10 ｼｽﾃﾑID       */
 , YKNO         INTEGER                         DEFAULT 0   NOT NULL            /*  20 要求NO       */
 , ERRMSG       varchar           ( 4000 )                                      /*  30 ｴﾗｰﾒｯｾｰｼﾞ    */
 , UNIQSEQ      int IDENTITY(1,1)                                               /*  50 ｼｰｹﾝｽ番号    */
 , FGJ          varchar           (    1 )      DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        varchar           (   14 )                                      /* 820 登録日時     */
 , PGSET        varchar           (   10 )                                      /* 830 作成PG       */
 , PGPSET       varchar           (   10 )                                      /* 840 作成親PG     */
 , USRSET       varchar           (   10 )                                      /* 850 作成社員     */
 , DYUPD        varchar           (   14 )                                      /* 860 更新日時     */
 , PGUPD        varchar           (   10 )                                      /* 870 更新PG       */
 , PGPUPD       varchar           (   10 )                                      /* 880 更新親PG     */
 , USRUPD       varchar           (   10 )                                      /* 890 更新者       */
);
